@@ -447,7 +447,7 @@ class SQLiteHandler(object):
         # print(table.name)
         records = self.table_read_records(table.name)
         
-        print(records)
+        # print(records)
 
         records_found = []
         for record in records:
